#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class system:
    fluent_name = ...
    command_names = ...

    def print_process_statistics(self, ):
        """
        Fluent process information.
        """

    def print_system_statistics(self, ):
        """
        System information.
        """

    def print_gpgpu_statistics(self, ):
        """
        GPGPU information.
        """

    def print_time_statistics(self, ):
        """
        Time usage information.
        """

