#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_7 import option as option_cls
from .value_3 import value as value_cls
class degrees_of_freedom(Group):
    """
    'degrees_of_freedom' child.
    """

    fluent_name = "degrees-of-freedom"

    child_names = \
        ['option', 'value']

    option: option_cls = option_cls
    """
    option child of degrees_of_freedom.
    """
    value: value_cls = value_cls
    """
    value child of degrees_of_freedom.
    """
