#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class lwf_particle_inclusion_in_dpm_concentration_enabled(Boolean):
    """
    Include/exclude LWF particle mass in the calculation of DPM Concentration.
    """

    fluent_name = "lwf-particle-inclusion-in-dpm-concentration-enabled?"

