#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class injection_child:
    fluent_name = ...
    child_names = ...
    name = ...
    report_type = ...
    injection_list = ...
    boundaries = ...
    physics = ...
    per_injection = ...
    average_over = ...
    retain_instantaneous_values = ...
    mass_criterion = ...
    user_specified_origin_and_axis = ...
    origin = ...
    axis = ...
    show_unsteady_rate = ...
    inj_mass_rate_prev_time = ...
    inj_mass_rate_prev_mass = ...
    inj_mass_rate_last_flow = ...
    inj_mass_rate_last_tstp = ...
    command_names = ...

    def create_output_parameter(self, ):
        """
        'create_output_parameter' command.
        """

