#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class partition_surface_child:
    fluent_name = ...
    child_names = ...
    name = ...
    partition_1 = ...
    partition_2 = ...
    interior_cell_faces = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """

