#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class methods:
    fluent_name = ...
    child_names = ...
    p_v_coupling = ...
    flux_type = ...
    discretization_scheme = ...
    pseudo_time_method = ...
    unsteady_1st_order = ...
    unsteady_2nd_order = ...
    unsteady_2nd_order_bounded = ...
    unsteady_global_time = ...
    accelerated_non_iterative_time_marching = ...
    convergence_acceleration_for_stretched_meshes = ...
    expert = ...
    frozen_flux = ...
    gradient_scheme = ...
    high_order_term_relaxation = ...
    multiphase_numerics = ...
    nb_gradient_boundary_option = ...
    nita = ...
    nita_expert_controls = ...
    overset = ...
    phase_based_vof_discretization = ...
    reduced_rank_extrapolation = ...
    reduced_rank_extrapolation_options = ...
    residual_smoothing = ...
    vof_numerics = ...
    warped_face_gradient_correction = ...
    command_names = ...

    def set_solution_methods_to_default(self, ):
        """
        Set solution methods to default values.
        """

