#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .udf_zmotion_name import udf_zmotion_name as udf_zmotion_name_cls
from .axis_direction_1 import axis_direction as axis_direction_cls
from .axis_origin_1 import axis_origin as axis_origin_cls
from .cursys import cursys as cursys_cls
from .conical import conical as conical_cls
from .solid_omega import solid_omega as solid_omega_cls
from .solid_relative_to_thread import solid_relative_to_thread as solid_relative_to_thread_cls
from .solid_motion import solid_motion as solid_motion_cls
from .solid_motion_axis_direction import solid_motion_axis_direction as solid_motion_axis_direction_cls
from .solid_motion_axis_origin import solid_motion_axis_origin as solid_motion_axis_origin_cls
from .solid_motion_velocity import solid_motion_velocity as solid_motion_velocity_cls
from .solid_motion_zone_motion_function import solid_motion_zone_motion_function as solid_motion_zone_motion_function_cls
from .omega import omega as omega_cls
from .relative_to_thread import relative_to_thread as relative_to_thread_cls
from .motion_spec import motion_spec as motion_spec_cls
class disabled(Group):
    """
    Help not available.
    """

    fluent_name = "disabled"

    child_names = \
        ['udf_zmotion_name', 'axis_direction', 'axis_origin', 'cursys',
         'conical', 'solid_omega', 'solid_relative_to_thread', 'solid_motion',
         'solid_motion_axis_direction', 'solid_motion_axis_origin',
         'solid_motion_velocity', 'solid_motion_zone_motion_function',
         'omega', 'relative_to_thread', 'motion_spec']

    udf_zmotion_name: udf_zmotion_name_cls = udf_zmotion_name_cls
    """
    udf_zmotion_name child of disabled.
    """
    axis_direction: axis_direction_cls = axis_direction_cls
    """
    axis_direction child of disabled.
    """
    axis_origin: axis_origin_cls = axis_origin_cls
    """
    axis_origin child of disabled.
    """
    cursys: cursys_cls = cursys_cls
    """
    cursys child of disabled.
    """
    conical: conical_cls = conical_cls
    """
    conical child of disabled.
    """
    solid_omega: solid_omega_cls = solid_omega_cls
    """
    solid_omega child of disabled.
    """
    solid_relative_to_thread: solid_relative_to_thread_cls = solid_relative_to_thread_cls
    """
    solid_relative_to_thread child of disabled.
    """
    solid_motion: solid_motion_cls = solid_motion_cls
    """
    solid_motion child of disabled.
    """
    solid_motion_axis_direction: solid_motion_axis_direction_cls = solid_motion_axis_direction_cls
    """
    solid_motion_axis_direction child of disabled.
    """
    solid_motion_axis_origin: solid_motion_axis_origin_cls = solid_motion_axis_origin_cls
    """
    solid_motion_axis_origin child of disabled.
    """
    solid_motion_velocity: solid_motion_velocity_cls = solid_motion_velocity_cls
    """
    solid_motion_velocity child of disabled.
    """
    solid_motion_zone_motion_function: solid_motion_zone_motion_function_cls = solid_motion_zone_motion_function_cls
    """
    solid_motion_zone_motion_function child of disabled.
    """
    omega: omega_cls = omega_cls
    """
    omega child of disabled.
    """
    relative_to_thread: relative_to_thread_cls = relative_to_thread_cls
    """
    relative_to_thread child of disabled.
    """
    motion_spec: motion_spec_cls = motion_spec_cls
    """
    motion_spec child of disabled.
    """
