#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class number_of_bands:
    fluent_name = ...
    child_names = ...
    set_all_interfaces = ...
    command_names = ...

    def set_specific_interface(self, interface_number: int, bands: int):
        """
        Set number of band to be used for mixing.
        
        Parameters
        ----------
            interface_number : int
                Set number of band to be used for mixing.
            bands : int
                Set number of band to be used for mixing.
        
        """

