#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class volumes_child:
    fluent_name = ...
    child_names = ...
    name = ...
    home_options = ...
    transparency_options = ...
    isovalue_options = ...
    clip_box_options = ...
    clip_sphere_options = ...
    iso_values_colors_list = ...
    local_values_range_list = ...
    opacities_range_list = ...
    transfer_functions_list = ...
    clip_bound_values_list = ...
    volume_data_list = ...
    custom_update_attribute_list = ...
    compute_node_count = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """

