#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class geko_options:
    fluent_name = ...
    child_names = ...
    wall_distance_free = ...
    cjet = ...
    creal = ...
    cnw_sub = ...
    cjet_aux = ...
    cbf_lam = ...
    cbf_tur = ...
    command_names = ...

    def geko_defaults(self, ):
        """
        Set GEKO options to default.
        """

