#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class parametric_project:
    fluent_name = ...
    command_names = ...

    def new(self, project_filename: str):
        """
        Create New Project.
        
        Parameters
        ----------
            project_filename : str
                'project_filename' child.
        
        """

    def open(self, project_filename: str, load_case: bool):
        """
        Open project.
        
        Parameters
        ----------
            project_filename : str
                'project_filename' child.
            load_case : bool
                'load_case' child.
        
        """

    def save(self, ):
        """
        Save Project.
        """

    def save_as(self, project_filename: str):
        """
        Save As Project.
        
        Parameters
        ----------
            project_filename : str
                'project_filename' child.
        
        """

    def save_as_copy(self, project_filename: str, convert_to_managed: bool):
        """
        Save As Project.
        
        Parameters
        ----------
            project_filename : str
                'project_filename' child.
            convert_to_managed : bool
                'convert_to_managed' child.
        
        """

    def archive(self, archive_name: str):
        """
        Archive Project.
        
        Parameters
        ----------
            archive_name : str
                'archive_name' child.
        
        """

