#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class set:
    fluent_name = ...
    child_names = ...
    cell_function = ...
    load_distribution = ...
    merge = ...
    partition_origin_vector = ...
    pre_test = ...
    smooth = ...
    print_verbosity = ...
    origin = ...
    laplace_smoothing = ...
    nfaces_as_weights = ...
    face_area_as_weights = ...
    layering = ...
    solid_thread_weight = ...
    stretched_mesh_enhancement = ...
    particle_weight = ...
    vof_free_surface_weight = ...
    isat_weight = ...
    fluid_solid_rebalance_after_read_case = ...
    model_weighted_partition = ...
    dpm_load_balancing = ...
    command_names = ...

    def across_zones(self, across_zone_boundaries: bool):
        """
        Enable partitioning by zone or by domain.
        
        Parameters
        ----------
            across_zone_boundaries : bool
                'across_zone_boundaries' child.
        
        """

    def all_off(self, ):
        """
        Disable all optimization.
        """

    def all_on(self, ):
        """
        Enable all optimization.
        """

