#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class unsteady_tracking:
    fluent_name = ...
    child_names = ...
    option = ...
    create_particles_every_dpm_step = ...
    dpm_time_step_size = ...
    number_of_time_steps = ...
    command_names = ...

    def clear_all_particles(self, ):
        """
        Clear all particles currently in the domain.
        """

