#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class report_plots_child:
    fluent_name = ...
    child_names = ...
    name = ...
    plot_window = ...
    frequency = ...
    flow_frequency = ...
    frequency_of = ...
    report_defs = ...
    print = ...
    title = ...
    x_label = ...
    y_label = ...
    active = ...
    plot_instantaneous_values = ...
    axes = ...
    curves = ...
    command_names = ...

    def plot(self, ):
        """
        Display the report-plot.
        """

