#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class participates_in_solar_ray_tracing(Boolean, _HasAllowedValuesMixin):
    """
    Participates in Solar Ray Tracing.
    """

    fluent_name = "participates-in-solar-ray-tracing"

