#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class surface_reaction_rate_temperature_factor(Real):
    """
    Set the surface reaction parameters for the Non-Equilibrium Thermal Model: Surface reaction-rate temperature factor.
    """

    fluent_name = "surface-reaction-rate-temperature-factor"

