#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class timer:
    fluent_name = ...
    command_names = ...

    def usage(self, ):
        """
        Print solver timer.
        """

    def reset(self, ):
        """
        Reset domain timers.
        """

