#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class multi_layer_refinement:
    fluent_name = ...
    child_names = ...
    type = ...
    layer_count = ...
    boundary_list = ...
    command_names = ...

    def refine_mesh(self, ):
        """
        Refine the mesh for multiple boundary layers.
        """

