#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class auto_options:
    fluent_name = ...
    child_names = ...
    proximity_tolerance = ...
    set_default_name_prefix = ...
    set_one_to_one_pairing_tolerance = ...
    set_minimum_area_percentage = ...
    pairing_between_different_cell_zones_only = ...
    pairing_between_interface_zones_only = ...
    keep_empty_interface = ...
    command_names = ...

    def naming_option(self, option: int, change_all_o2o_si_names: bool):
        """
        Specify whether or not to include an informative suffix to the mesh interface name.
        
        Parameters
        ----------
            option : int
                'option' child.
            change_all_o2o_si_names : bool
                'change_all_o2o_si_names' child.
        
        """

