#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class olic_child:
    fluent_name = ...
    child_names = ...
    name = ...
    field = ...
    vector_field = ...
    vector_phase = ...
    surfaces_list = ...
    surfaces = ...
    lic_color_by_field = ...
    lic_color = ...
    lic_oriented = ...
    lic_normalize = ...
    lic_pixel_interpolation = ...
    lic_max_steps = ...
    texture_spacing = ...
    texture_size = ...
    lic_intensity_factor = ...
    lic_image_filter = ...
    lic_intensity_alpha = ...
    lic_fast = ...
    gray_scale = ...
    image_to_display = ...
    range_option = ...
    color_map = ...
    draw_mesh = ...
    mesh_object = ...
    display_state_name = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """

