#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class sc_def_file_settings:
    fluent_name = ...
    child_names = ...
    enable_auto_creation_of_scp_file = ...
    command_names = ...

    def write_sc_file(self, file_name: str):
        """
        Write a Fluent Input File for System Coupling.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

