#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class extrapolate_eqn_vars:
    fluent_name = ...
    command_names = ...

    def list(self, ):
        """
        'list' command.
        """

    def list_properties(self, object_name: str):
        """
        'list_properties' command.
        
        Parameters
        ----------
            object_name : str
                'object_name' child.
        
        """

    def duplicate(self, from_: str, to: str):
        """
        'duplicate' command.
        
        Parameters
        ----------
            from_ : str
                'from' child.
            to : str
                'to' child.
        
        """

    <class 'ansys.fluent.core.solver.flobject.child_object_type'> = ...
