#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class solar_load:
    fluent_name = ...
    child_names = ...
    solar_model = ...
    sun_direction_vector = ...
    illumination_parameters = ...
    quad_tree_parameters = ...
    ground_reflectivity = ...
    scattering_fraction = ...
    solar_on_adjacent_fluid = ...
    direction_from_solar_calculator = ...
    solar_load_frequency = ...
    solar_calculator = ...
    apply_full_solar_irradiation = ...
    autoread_solar_data = ...
    autosave_solar_data = ...
    command_names = ...

    def solar_on_demand(self, ):
        """
        Enable  solar load on demand.
        """

