#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .les_spec import les_spec as les_spec_cls
from .fluctuating_velocity_algorithm import fluctuating_velocity_algorithm as fluctuating_velocity_algorithm_cls
from .number_of_fourier_modes import number_of_fourier_modes as number_of_fourier_modes_cls
from .number_of_vortices import number_of_vortices as number_of_vortices_cls
from .include_streamwise_fluctuations import include_streamwise_fluctuations as include_streamwise_fluctuations_cls
from .satisfy_mass_conservation import satisfy_mass_conservation as satisfy_mass_conservation_cls
from .scale_search_limiter import scale_search_limiter as scale_search_limiter_cls
from .turbulent_intensity_perc import turbulent_intensity_perc as turbulent_intensity_perc_cls
from .turbulent_viscosity_ratio_stg import turbulent_viscosity_ratio_stg as turbulent_viscosity_ratio_stg_cls
from .wall_distance import wall_distance as wall_distance_cls
from .volumetric_forcing import volumetric_forcing as volumetric_forcing_cls
from .forcing_zone_thickness import forcing_zone_thickness as forcing_zone_thickness_cls
from .volumetric_thickness import volumetric_thickness as volumetric_thickness_cls
from .turbulent_specification import turbulent_specification as turbulent_specification_cls
from .modified_turbulent_viscosity_1 import modified_turbulent_viscosity as modified_turbulent_viscosity_cls
from .laminar_kinetic_energy_1 import laminar_kinetic_energy as laminar_kinetic_energy_cls
from .intermittency_1 import intermittency as intermittency_cls
from .turbulent_kinetic_energy_1 import turbulent_kinetic_energy as turbulent_kinetic_energy_cls
from .turbulent_dissipation_rate_1 import turbulent_dissipation_rate as turbulent_dissipation_rate_cls
from .specific_dissipation_rate_1 import specific_dissipation_rate as specific_dissipation_rate_cls
from .velocity_variance_scale_1 import velocity_variance_scale as velocity_variance_scale_cls
from .turbulent_intensity_1 import turbulent_intensity as turbulent_intensity_cls
from .turbulent_length_scale_1 import turbulent_length_scale as turbulent_length_scale_cls
from .hydraulic_diameter_1 import hydraulic_diameter as hydraulic_diameter_cls
from .turbulent_viscosity_ratio_real_1 import turbulent_viscosity_ratio_real as turbulent_viscosity_ratio_real_cls
from .turbulent_viscosity_ratio_1 import turbulent_viscosity_ratio as turbulent_viscosity_ratio_cls
from .reynolds_stress_specification import reynolds_stress_specification as reynolds_stress_specification_cls
from .uu_reynolds_stresses_1 import uu_reynolds_stresses as uu_reynolds_stresses_cls
from .vv_reynolds_stresses_1 import vv_reynolds_stresses as vv_reynolds_stresses_cls
from .ww_reynolds_stresses_1 import ww_reynolds_stresses as ww_reynolds_stresses_cls
from .uv_reynolds_stresses_1 import uv_reynolds_stresses as uv_reynolds_stresses_cls
from .vw_reynolds_stresses_1 import vw_reynolds_stresses as vw_reynolds_stresses_cls
from .uw_reynolds_stresses_1 import uw_reynolds_stresses as uw_reynolds_stresses_cls
from .subgrid_kinetic_energy_specification import subgrid_kinetic_energy_specification as subgrid_kinetic_energy_specification_cls
from .subgrid_kinetic_energy import subgrid_kinetic_energy as subgrid_kinetic_energy_cls
from .subgrid_turbulent_intensity import subgrid_turbulent_intensity as subgrid_turbulent_intensity_cls
class turbulence(Group):
    """
    Help not available.
    """

    fluent_name = "turbulence"

    child_names = \
        ['les_spec', 'fluctuating_velocity_algorithm',
         'number_of_fourier_modes', 'number_of_vortices',
         'include_streamwise_fluctuations', 'satisfy_mass_conservation',
         'scale_search_limiter', 'turbulent_intensity_perc',
         'turbulent_viscosity_ratio_stg', 'wall_distance',
         'volumetric_forcing', 'forcing_zone_thickness',
         'volumetric_thickness', 'turbulent_specification',
         'modified_turbulent_viscosity', 'laminar_kinetic_energy',
         'intermittency', 'turbulent_kinetic_energy',
         'turbulent_dissipation_rate', 'specific_dissipation_rate',
         'velocity_variance_scale', 'turbulent_intensity',
         'turbulent_length_scale', 'hydraulic_diameter',
         'turbulent_viscosity_ratio_real', 'turbulent_viscosity_ratio',
         'reynolds_stress_specification', 'uu_reynolds_stresses',
         'vv_reynolds_stresses', 'ww_reynolds_stresses',
         'uv_reynolds_stresses', 'vw_reynolds_stresses',
         'uw_reynolds_stresses', 'subgrid_kinetic_energy_specification',
         'subgrid_kinetic_energy', 'subgrid_turbulent_intensity']

    les_spec: les_spec_cls = les_spec_cls
    """
    les_spec child of turbulence.
    """
    fluctuating_velocity_algorithm: fluctuating_velocity_algorithm_cls = fluctuating_velocity_algorithm_cls
    """
    fluctuating_velocity_algorithm child of turbulence.
    """
    number_of_fourier_modes: number_of_fourier_modes_cls = number_of_fourier_modes_cls
    """
    number_of_fourier_modes child of turbulence.
    """
    number_of_vortices: number_of_vortices_cls = number_of_vortices_cls
    """
    number_of_vortices child of turbulence.
    """
    include_streamwise_fluctuations: include_streamwise_fluctuations_cls = include_streamwise_fluctuations_cls
    """
    include_streamwise_fluctuations child of turbulence.
    """
    satisfy_mass_conservation: satisfy_mass_conservation_cls = satisfy_mass_conservation_cls
    """
    satisfy_mass_conservation child of turbulence.
    """
    scale_search_limiter: scale_search_limiter_cls = scale_search_limiter_cls
    """
    scale_search_limiter child of turbulence.
    """
    turbulent_intensity_perc: turbulent_intensity_perc_cls = turbulent_intensity_perc_cls
    """
    turbulent_intensity_perc child of turbulence.
    """
    turbulent_viscosity_ratio_stg: turbulent_viscosity_ratio_stg_cls = turbulent_viscosity_ratio_stg_cls
    """
    turbulent_viscosity_ratio_stg child of turbulence.
    """
    wall_distance: wall_distance_cls = wall_distance_cls
    """
    wall_distance child of turbulence.
    """
    volumetric_forcing: volumetric_forcing_cls = volumetric_forcing_cls
    """
    volumetric_forcing child of turbulence.
    """
    forcing_zone_thickness: forcing_zone_thickness_cls = forcing_zone_thickness_cls
    """
    forcing_zone_thickness child of turbulence.
    """
    volumetric_thickness: volumetric_thickness_cls = volumetric_thickness_cls
    """
    volumetric_thickness child of turbulence.
    """
    turbulent_specification: turbulent_specification_cls = turbulent_specification_cls
    """
    turbulent_specification child of turbulence.
    """
    modified_turbulent_viscosity: modified_turbulent_viscosity_cls = modified_turbulent_viscosity_cls
    """
    modified_turbulent_viscosity child of turbulence.
    """
    laminar_kinetic_energy: laminar_kinetic_energy_cls = laminar_kinetic_energy_cls
    """
    laminar_kinetic_energy child of turbulence.
    """
    intermittency: intermittency_cls = intermittency_cls
    """
    intermittency child of turbulence.
    """
    turbulent_kinetic_energy: turbulent_kinetic_energy_cls = turbulent_kinetic_energy_cls
    """
    turbulent_kinetic_energy child of turbulence.
    """
    turbulent_dissipation_rate: turbulent_dissipation_rate_cls = turbulent_dissipation_rate_cls
    """
    turbulent_dissipation_rate child of turbulence.
    """
    specific_dissipation_rate: specific_dissipation_rate_cls = specific_dissipation_rate_cls
    """
    specific_dissipation_rate child of turbulence.
    """
    velocity_variance_scale: velocity_variance_scale_cls = velocity_variance_scale_cls
    """
    velocity_variance_scale child of turbulence.
    """
    turbulent_intensity: turbulent_intensity_cls = turbulent_intensity_cls
    """
    turbulent_intensity child of turbulence.
    """
    turbulent_length_scale: turbulent_length_scale_cls = turbulent_length_scale_cls
    """
    turbulent_length_scale child of turbulence.
    """
    hydraulic_diameter: hydraulic_diameter_cls = hydraulic_diameter_cls
    """
    hydraulic_diameter child of turbulence.
    """
    turbulent_viscosity_ratio_real: turbulent_viscosity_ratio_real_cls = turbulent_viscosity_ratio_real_cls
    """
    turbulent_viscosity_ratio_real child of turbulence.
    """
    turbulent_viscosity_ratio: turbulent_viscosity_ratio_cls = turbulent_viscosity_ratio_cls
    """
    turbulent_viscosity_ratio child of turbulence.
    """
    reynolds_stress_specification: reynolds_stress_specification_cls = reynolds_stress_specification_cls
    """
    reynolds_stress_specification child of turbulence.
    """
    uu_reynolds_stresses: uu_reynolds_stresses_cls = uu_reynolds_stresses_cls
    """
    uu_reynolds_stresses child of turbulence.
    """
    vv_reynolds_stresses: vv_reynolds_stresses_cls = vv_reynolds_stresses_cls
    """
    vv_reynolds_stresses child of turbulence.
    """
    ww_reynolds_stresses: ww_reynolds_stresses_cls = ww_reynolds_stresses_cls
    """
    ww_reynolds_stresses child of turbulence.
    """
    uv_reynolds_stresses: uv_reynolds_stresses_cls = uv_reynolds_stresses_cls
    """
    uv_reynolds_stresses child of turbulence.
    """
    vw_reynolds_stresses: vw_reynolds_stresses_cls = vw_reynolds_stresses_cls
    """
    vw_reynolds_stresses child of turbulence.
    """
    uw_reynolds_stresses: uw_reynolds_stresses_cls = uw_reynolds_stresses_cls
    """
    uw_reynolds_stresses child of turbulence.
    """
    subgrid_kinetic_energy_specification: subgrid_kinetic_energy_specification_cls = subgrid_kinetic_energy_specification_cls
    """
    subgrid_kinetic_energy_specification child of turbulence.
    """
    subgrid_kinetic_energy: subgrid_kinetic_energy_cls = subgrid_kinetic_energy_cls
    """
    subgrid_kinetic_energy child of turbulence.
    """
    subgrid_turbulent_intensity: subgrid_turbulent_intensity_cls = subgrid_turbulent_intensity_cls
    """
    subgrid_turbulent_intensity child of turbulence.
    """
