#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class picture_options:
    fluent_name = ...
    child_names = ...
    color_mode = ...
    invert_background = ...
    driver_options = ...
    standard_resolution = ...
    jpeg_hardcopy_quality = ...
    landscape = ...
    x_resolution = ...
    y_resolution = ...
    dpi = ...
    use_window_resolution = ...
    command_names = ...

    def list_color_mode(self, ):
        """
        'list_color_mode' command.
        """

    def preview(self, ):
        """
        Display a preview image of a hardcopy.
        """

