#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class fmg_initialization:
    fluent_name = ...
    child_names = ...
    fmg_courant_number = ...
    enable_fmg_verbose = ...
    command_names = ...

    def customize_fmg_initialization(self, multi_level_grid: int, residual_reduction_level: List[Union[float, str]], cycle_count: List[Union[float, str]]):
        """
        'customize_fmg_initialization' command.
        
        Parameters
        ----------
            multi_level_grid : int
                'multi_level_grid' child.
            residual_reduction_level : typing.List[real]
                'residual_reduction_level' child.
            cycle_count : typing.List[real]
                'cycle_count' child.
        
        """

