#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class raytracing_options:
    fluent_name = ...
    child_names = ...
    background = ...
    rendering = ...
    command_names = ...

    def display_live_preview(self, ):
        """
        Display the raytracing rendering for the active window.
        """

