#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .chemical_formula import chemical_formula as chemical_formula_cls
from .density_4 import density as density_cls
from .thermal_conductivity_3 import thermal_conductivity as thermal_conductivity_cls
from .latent_heat_1 import latent_heat as latent_heat_cls
from .volatile_fraction import volatile_fraction as volatile_fraction_cls
from .combustible_fraction import combustible_fraction as combustible_fraction_cls
from .swelling_coefficient import swelling_coefficient as swelling_coefficient_cls
from .burn_stoichiometry import burn_stoichiometry as burn_stoichiometry_cls
from .specific_heat_3 import specific_heat as specific_heat_cls
from .binary_diffusivity_2 import binary_diffusivity as binary_diffusivity_cls
from .diffusivity_reference_pressure import diffusivity_reference_pressure as diffusivity_reference_pressure_cls
from .vaporization_temperature import vaporization_temperature as vaporization_temperature_cls
from .thermophoretic_co import thermophoretic_co as thermophoretic_co_cls
from .burn_hreact import burn_hreact as burn_hreact_cls
from .burn_hreact_fraction import burn_hreact_fraction as burn_hreact_fraction_cls
from .devolatilization_model import devolatilization_model as devolatilization_model_cls
from .combustion_model import combustion_model as combustion_model_cls
from .scattering_factor_1 import scattering_factor as scattering_factor_cls
from .emissivity_1 import emissivity as emissivity_cls
class combusting_particle_child(Group):
    """
    'child_object_type' of combusting_particle.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'chemical_formula', 'density', 'thermal_conductivity',
         'latent_heat', 'volatile_fraction', 'combustible_fraction',
         'swelling_coefficient', 'burn_stoichiometry', 'specific_heat',
         'binary_diffusivity', 'diffusivity_reference_pressure',
         'vaporization_temperature', 'thermophoretic_co', 'burn_hreact',
         'burn_hreact_fraction', 'devolatilization_model', 'combustion_model',
         'scattering_factor', 'emissivity']

    name: name_cls = name_cls
    """
    name child of combusting_particle_child.
    """
    chemical_formula: chemical_formula_cls = chemical_formula_cls
    """
    chemical_formula child of combusting_particle_child.
    """
    density: density_cls = density_cls
    """
    density child of combusting_particle_child.
    """
    thermal_conductivity: thermal_conductivity_cls = thermal_conductivity_cls
    """
    thermal_conductivity child of combusting_particle_child.
    """
    latent_heat: latent_heat_cls = latent_heat_cls
    """
    latent_heat child of combusting_particle_child.
    """
    volatile_fraction: volatile_fraction_cls = volatile_fraction_cls
    """
    volatile_fraction child of combusting_particle_child.
    """
    combustible_fraction: combustible_fraction_cls = combustible_fraction_cls
    """
    combustible_fraction child of combusting_particle_child.
    """
    swelling_coefficient: swelling_coefficient_cls = swelling_coefficient_cls
    """
    swelling_coefficient child of combusting_particle_child.
    """
    burn_stoichiometry: burn_stoichiometry_cls = burn_stoichiometry_cls
    """
    burn_stoichiometry child of combusting_particle_child.
    """
    specific_heat: specific_heat_cls = specific_heat_cls
    """
    specific_heat child of combusting_particle_child.
    """
    binary_diffusivity: binary_diffusivity_cls = binary_diffusivity_cls
    """
    binary_diffusivity child of combusting_particle_child.
    """
    diffusivity_reference_pressure: diffusivity_reference_pressure_cls = diffusivity_reference_pressure_cls
    """
    diffusivity_reference_pressure child of combusting_particle_child.
    """
    vaporization_temperature: vaporization_temperature_cls = vaporization_temperature_cls
    """
    vaporization_temperature child of combusting_particle_child.
    """
    thermophoretic_co: thermophoretic_co_cls = thermophoretic_co_cls
    """
    thermophoretic_co child of combusting_particle_child.
    """
    burn_hreact: burn_hreact_cls = burn_hreact_cls
    """
    burn_hreact child of combusting_particle_child.
    """
    burn_hreact_fraction: burn_hreact_fraction_cls = burn_hreact_fraction_cls
    """
    burn_hreact_fraction child of combusting_particle_child.
    """
    devolatilization_model: devolatilization_model_cls = devolatilization_model_cls
    """
    devolatilization_model child of combusting_particle_child.
    """
    combustion_model: combustion_model_cls = combustion_model_cls
    """
    combustion_model child of combusting_particle_child.
    """
    scattering_factor: scattering_factor_cls = scattering_factor_cls
    """
    scattering_factor child of combusting_particle_child.
    """
    emissivity: emissivity_cls = emissivity_cls
    """
    emissivity child of combusting_particle_child.
    """
