#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class named_expressions_child:
    fluent_name = ...
    child_names = ...
    name = ...
    definition = ...
    description = ...
    parameterid = ...
    parametername = ...
    unit = ...
    input_parameter = ...
    output_parameter = ...
    def get_value(self, ):
        """
        'get_value' query.
        """

