#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class transparency_options:
    fluent_name = ...
    child_names = ...
    settings = ...
    command_names = ...

    def reset(self, ):
        """
        'reset' command.
        """

    def invert(self, ):
        """
        'invert' command.
        """

