#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class xy_plot_child:
    fluent_name = ...
    child_names = ...
    name = ...
    uid = ...
    options = ...
    plot_direction = ...
    x_axis_function = ...
    y_axis_function = ...
    surfaces_list = ...
    physics = ...
    geometry = ...
    surfaces = ...
    axes = ...
    curves = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """

    def write_to_file(self, filename: str):
        """
        Write data to file.
        
        Parameters
        ----------
            filename : str
                Enter file name.
        
        """

    def read_from_file(self, filename: str):
        """
        Read data from file.
        
        Parameters
        ----------
            filename : str
                Enter file name.
        
        """

    def free_file_data(self, file_data_list: List[str]):
        """
        Free file-data.
        
        Parameters
        ----------
            file_data_list : typing.List[str]
                File-data to delete.
        
        """

