#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class vof_smooth_options:
    fluent_name = ...
    child_names = ...
    patch_reconstructed_interface = ...
    use_volumetric_smoothing = ...
    smoothing_relaxation_factor = ...
    command_names = ...

    def execute_smoothing(self, ):
        """
        Execute volumetric smoothing for volume fraction.
        """

