#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class operating_density:
    fluent_name = ...
    child_names = ...
    enable = ...
    method = ...
    value = ...
    command_names = ...

    def print(self, ):
        """
        Print operating density value.
        """

