#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class parallel:
    fluent_name = ...
    child_names = ...
    thread_number_control = ...
    check_verbosity = ...
    partition = ...
    set = ...
    load_balance = ...
    multidomain = ...
    network = ...
    timer = ...
    command_names = ...

    def check(self, ):
        """
        Parallel check.
        """

    def show_connectivity(self, compute_node: int):
        """
        Show machine connectivity.
        
        Parameters
        ----------
            compute_node : int
                'compute_node' child.
        
        """

    def latency(self, ):
        """
        Show network latency.
        """

    def bandwidth(self, ):
        """
        Show network bandwidth.
        """

