#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class report_definitions:
    fluent_name = ...
    child_names = ...
    mesh = ...
    surface = ...
    volume = ...
    force = ...
    lift = ...
    drag = ...
    moment = ...
    flux = ...
    injection = ...
    user_defined = ...
    aeromechanics = ...
    icing = ...
    expression = ...
    single_val_expression = ...
    custom = ...
    command_names = ...

    def compute(self, report_defs: List[str]):
        """
        'compute' command.
        
        Parameters
        ----------
            report_defs : typing.List[str]
                'report_defs' child.
        
        """

    def copy(self, copy_from: str, copy_to: str):
        """
        'copy' command.
        
        Parameters
        ----------
            copy_from : str
                'copy_from' child.
            copy_to : str
                'copy_to' child.
        
        """

    def list(self, ):
        """
        'list' command.
        """

