#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class poor_mesh_numerics:
    fluent_name = ...
    child_names = ...
    set = ...
    command_names = ...

    def list_properties(self, ):
        """
        List the properties of a definition for automatic poor mesh numerics.
        """

