#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class multi_layer_refinement:
    fluent_name = ...
    command_names = ...

    def refine_mesh(self, ):
        """
        Refine the mesh for multiple boundary layers.
        """

    def boundary_zones(self, ):
        """
        Specify boundary zones for refinement.
        """

    def layer_count(self, ):
        """
        Specify the layer count for refinement.
        """

    def parameters(self, ):
        """
        Specify parameters for multiple boundary layer refinement.
        """

