#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class by_type:
    fluent_name = ...
    child_names = ...
    only_list_case_boundaries = ...
    use_inherent_material_color = ...
    type_name = ...
    command_names = ...

    def reset(self, ):
        """
        To reset colors and/or materials to the defaults.
        """

