#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class contour_child:
    fluent_name = ...
    child_names = ...
    name = ...
    field = ...
    filled = ...
    boundary_values = ...
    contour_lines = ...
    node_values = ...
    surfaces_list = ...
    range_option = ...
    coloring = ...
    color_map = ...
    draw_mesh = ...
    mesh_object = ...
    display_state_name = ...
    physics = ...
    geometry = ...
    surfaces = ...
    deformation = ...
    deformation_scale = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """

    def update_min_max(self, ):
        """
        'update_min_max' command.
        """

