#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class histogram:
    fluent_name = ...
    child_names = ...
    cell_function = ...
    auto_range = ...
    minimum = ...
    maximum = ...
    num_divisions = ...
    all_zones = ...
    zones = ...
    axes = ...
    curves = ...
    command_names = ...

    def print(self, ):
        """
        Print a histogram of a scalar quantity.
        """

    def plot(self, ):
        """
        Plot a histogram of a scalar quantity.
        """

    def write(self, file_name: str):
        """
        Write a histogram of a scalar quantity to a file.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

