#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class rendering_options:
    fluent_name = ...
    child_names = ...
    animation_option = ...
    auto_spin = ...
    color_map_alignment = ...
    double_buffering = ...
    face_displacement = ...
    hidden_surface_method = ...
    hidden_surfaces = ...
    front_faces_transparent = ...
    show_colormap = ...
    command_names = ...

    def device_info(self, ):
        """
        List information for the graphics device.
        """

    def driver(self, driver_name: str):
        """
        Change the current graphics driver.
        
        Parameters
        ----------
            driver_name : str
                'driver_name' child.
        
        """

    def set_rendering_options(self, ):
        """
        Set the rendering options.
        """

