#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class bodies_child:
    fluent_name = ...
    child_names = ...
    name = ...
    faces = ...
    command_names = ...

    def list_properties(self, ):
        """
        'list_properties' command.
        """

