#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class pathline_child:
    fluent_name = ...
    child_names = ...
    name = ...
    uid = ...
    options = ...
    range = ...
    style_attribute = ...
    accuracy_control = ...
    plot = ...
    step = ...
    skip = ...
    coarsen = ...
    onzone = ...
    onphysics = ...
    field = ...
    surfaces_list = ...
    velocity_domain = ...
    color_map = ...
    draw_mesh = ...
    mesh_object = ...
    display_state_name = ...
    physics = ...
    geometry = ...
    surfaces = ...
    axes = ...
    curves = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """

    def update_min_max(self, ):
        """
        'update_min_max' command.
        """

