#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class contact_solution_controls:
    fluent_name = ...
    child_names = ...
    solution_stabilization = ...
    verbosity = ...
    parameters = ...
    spatial = ...
    transient = ...
    amg = ...
    models = ...
    methods = ...
    miscellaneous = ...
    command_names = ...

    def set_settings_to_default(self, ):
        """
        Set contact solution stabilization to default.
        """

