#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class use_beeam_direction_from_solar_load_model_settings(Boolean, _HasAllowedValuesMixin):
    """
    Use Beam Direction from Solar Load Model Settings.
    """

    fluent_name = "use-beeam-direction-from-solar-load-model-settings"

