#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class colors:
    fluent_name = ...
    child_names = ...
    background = ...
    color_by_type = ...
    foreground = ...
    by_type = ...
    by_surface = ...
    far_field_faces = ...
    inlet_faces = ...
    interior_faces = ...
    internal_faces = ...
    outlet_faces = ...
    overset_faces = ...
    periodic_faces = ...
    rans_les_interface_faces = ...
    symmetry_faces = ...
    axis_faces = ...
    free_surface_faces = ...
    traction_faces = ...
    wall_faces = ...
    interface_faces = ...
    surface = ...
    skip_label = ...
    automatic_skip = ...
    command_names = ...

    def reset_colors(self, ):
        """
        Reset individual mesh surface colors to the defaults.
        """

    def list_colors(self, ):
        """
        List available colors.
        """

