#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class dynamic_mechanism_reduction_min_target(Integer):
    """
    Specify minimum number of target species for dynamic mechanism reduction.
    """

    fluent_name = "dynamic-mechanism-reduction-min-target"

