#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .a import a as a_cls
from .b import b as b_cls
from .c import c as c_cls
from .d import d as d_cls
from .e import e as e_cls
class gupta_curve_fit_conductivity(Group):
    """
    'gupta_curve_fit_conductivity' child.
    """

    fluent_name = "gupta-curve-fit-conductivity"

    child_names = \
        ['a', 'b', 'c', 'd', 'e']

    a: a_cls = a_cls
    """
    a child of gupta_curve_fit_conductivity.
    """
    b: b_cls = b_cls
    """
    b child of gupta_curve_fit_conductivity.
    """
    c: c_cls = c_cls
    """
    c child of gupta_curve_fit_conductivity.
    """
    d: d_cls = d_cls
    """
    d child of gupta_curve_fit_conductivity.
    """
    e: e_cls = e_cls
    """
    e child of gupta_curve_fit_conductivity.
    """
