#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class vector_child:
    fluent_name = ...
    child_names = ...
    name = ...
    field = ...
    vector_field = ...
    surfaces_list = ...
    scale = ...
    style = ...
    skip = ...
    vector_opt = ...
    range_option = ...
    color_map = ...
    draw_mesh = ...
    mesh_object = ...
    display_state_name = ...
    physics = ...
    geometry = ...
    surfaces = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """

