#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class make_steady_from_unsteady_file(Boolean):
    """
    Specify whether the unsteady sample is to be reduced into a steady-state injection file.
    """

    fluent_name = "make-steady-from-unsteady-file?"

