#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .potential import potential as potential_cls
from .joule_heating import joule_heating as joule_heating_cls
from .li_battery_enabled import li_battery_enabled as li_battery_enabled_cls
from .echemistry_enabled import echemistry_enabled as echemistry_enabled_cls
from .lithium_battery import lithium_battery as lithium_battery_cls
from .electrolysis import electrolysis as electrolysis_cls
class echemistry(Group):
    """
    Enter the potential/echemistry model settings.
    """

    fluent_name = "echemistry"

    child_names = \
        ['potential', 'joule_heating', 'li_battery_enabled',
         'echemistry_enabled', 'lithium_battery', 'electrolysis']

    potential: potential_cls = potential_cls
    """
    potential child of echemistry.
    """
    joule_heating: joule_heating_cls = joule_heating_cls
    """
    joule_heating child of echemistry.
    """
    li_battery_enabled: li_battery_enabled_cls = li_battery_enabled_cls
    """
    li_battery_enabled child of echemistry.
    """
    echemistry_enabled: echemistry_enabled_cls = echemistry_enabled_cls
    """
    echemistry_enabled child of echemistry.
    """
    lithium_battery: lithium_battery_cls = lithium_battery_cls
    """
    lithium_battery child of echemistry.
    """
    electrolysis: electrolysis_cls = electrolysis_cls
    """
    electrolysis child of echemistry.
    """
