#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class set:
    fluent_name = ...
    child_names = ...
    adaption_method = ...
    prismatic_boundary_zones = ...
    cell_zones = ...
    dynamic_adaption_frequency = ...
    verbosity = ...
    encapsulate_children = ...
    maximum_refinement_level = ...
    minimum_edge_length = ...
    minimum_cell_quality = ...
    maximum_cell_count = ...
    additional_refinement_layers = ...
    prismatic_adaption = ...
    prismatic_split_ratio = ...
    overset_adapt_dead_cells = ...
    command_names = ...

    def dynamic_adaption(self, enable: bool):
        """
        Adapt the mesh during solution.
        
        Parameters
        ----------
            enable : bool
                'enable' child.
        
        """

