#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class convert_hanging_nodes_during_read(Boolean):
    """
    Indicate whether meshes with hanging-nodes will be converted to polyhedra while reading.
    """

    fluent_name = "convert-hanging-nodes-during-read?"

