#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .porous_jump_turb_wall_treatment import porous_jump_turb_wall_treatment as porous_jump_turb_wall_treatment_cls
from .dir import dir as dir_cls
from .average_dp import average_dp as average_dp_cls
from .pressure_jump import pressure_jump as pressure_jump_cls
from .limit_range import limit_range as limit_range_cls
from .v_min import v_min as v_min_cls
from .v_max import v_max as v_max_cls
from .strength import strength as strength_cls
from .profile_dp import profile_dp as profile_dp_cls
from .dp_profile import dp_profile as dp_profile_cls
from .swirl_model import swirl_model as swirl_model_cls
from .fan_vr import fan_vr as fan_vr_cls
from .fr import fr as fr_cls
from .hub import hub as hub_cls
from .axis_origin_2 import axis_origin as axis_origin_cls
from .axis_direction_2 import axis_direction as axis_direction_cls
from .profile_vt import profile_vt as profile_vt_cls
from .vt_profile import vt_profile as vt_profile_cls
from .profile_vr import profile_vr as profile_vr_cls
from .vr_profile import vr_profile as vr_profile_cls
from .swirl_factor import swirl_factor as swirl_factor_cls
from .discrete_phase_bc_type import discrete_phase_bc_type as discrete_phase_bc_type_cls
from .dem_collision_partner import dem_collision_partner as dem_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .discrete_phase_bc_function import discrete_phase_bc_function as discrete_phase_bc_function_cls
from .new_fan_definition import new_fan_definition as new_fan_definition_cls
class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread',
         'porous_jump_turb_wall_treatment', 'dir', 'average_dp',
         'pressure_jump', 'limit_range', 'v_min', 'v_max', 'strength',
         'profile_dp', 'dp_profile', 'swirl_model', 'fan_vr', 'fr', 'hub',
         'axis_origin', 'axis_direction', 'profile_vt', 'vt_profile',
         'profile_vr', 'vr_profile', 'swirl_factor', 'discrete_phase_bc_type',
         'dem_collision_partner', 'reinj_inj', 'discrete_phase_bc_function',
         'new_fan_definition']

    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of phase_child.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of phase_child.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of phase_child.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of phase_child.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of phase_child.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of phase_child.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of phase_child.
    """
    porous_jump_turb_wall_treatment: porous_jump_turb_wall_treatment_cls = porous_jump_turb_wall_treatment_cls
    """
    porous_jump_turb_wall_treatment child of phase_child.
    """
    dir: dir_cls = dir_cls
    """
    dir child of phase_child.
    """
    average_dp: average_dp_cls = average_dp_cls
    """
    average_dp child of phase_child.
    """
    pressure_jump: pressure_jump_cls = pressure_jump_cls
    """
    pressure_jump child of phase_child.
    """
    limit_range: limit_range_cls = limit_range_cls
    """
    limit_range child of phase_child.
    """
    v_min: v_min_cls = v_min_cls
    """
    v_min child of phase_child.
    """
    v_max: v_max_cls = v_max_cls
    """
    v_max child of phase_child.
    """
    strength: strength_cls = strength_cls
    """
    strength child of phase_child.
    """
    profile_dp: profile_dp_cls = profile_dp_cls
    """
    profile_dp child of phase_child.
    """
    dp_profile: dp_profile_cls = dp_profile_cls
    """
    dp_profile child of phase_child.
    """
    swirl_model: swirl_model_cls = swirl_model_cls
    """
    swirl_model child of phase_child.
    """
    fan_vr: fan_vr_cls = fan_vr_cls
    """
    fan_vr child of phase_child.
    """
    fr: fr_cls = fr_cls
    """
    fr child of phase_child.
    """
    hub: hub_cls = hub_cls
    """
    hub child of phase_child.
    """
    axis_origin: axis_origin_cls = axis_origin_cls
    """
    axis_origin child of phase_child.
    """
    axis_direction: axis_direction_cls = axis_direction_cls
    """
    axis_direction child of phase_child.
    """
    profile_vt: profile_vt_cls = profile_vt_cls
    """
    profile_vt child of phase_child.
    """
    vt_profile: vt_profile_cls = vt_profile_cls
    """
    vt_profile child of phase_child.
    """
    profile_vr: profile_vr_cls = profile_vr_cls
    """
    profile_vr child of phase_child.
    """
    vr_profile: vr_profile_cls = vr_profile_cls
    """
    vr_profile child of phase_child.
    """
    swirl_factor: swirl_factor_cls = swirl_factor_cls
    """
    swirl_factor child of phase_child.
    """
    discrete_phase_bc_type: discrete_phase_bc_type_cls = discrete_phase_bc_type_cls
    """
    discrete_phase_bc_type child of phase_child.
    """
    dem_collision_partner: dem_collision_partner_cls = dem_collision_partner_cls
    """
    dem_collision_partner child of phase_child.
    """
    reinj_inj: reinj_inj_cls = reinj_inj_cls
    """
    reinj_inj child of phase_child.
    """
    discrete_phase_bc_function: discrete_phase_bc_function_cls = discrete_phase_bc_function_cls
    """
    discrete_phase_bc_function child of phase_child.
    """
    new_fan_definition: new_fan_definition_cls = new_fan_definition_cls
    """
    new_fan_definition child of phase_child.
    """
