#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .courant_number_reduction import courant_number_reduction as courant_number_reduction_cls
from .correction_reduction import correction_reduction as correction_reduction_cls
from .correction_smoothing import correction_smoothing as correction_smoothing_cls
from .species_correction_reduction import species_correction_reduction as species_correction_reduction_cls
class relaxation_factor(Group):
    """
    'relaxation_factor' child.
    """

    fluent_name = "relaxation-factor"

    child_names = \
        ['courant_number_reduction', 'correction_reduction',
         'correction_smoothing', 'species_correction_reduction']

    courant_number_reduction: courant_number_reduction_cls = courant_number_reduction_cls
    """
    courant_number_reduction child of relaxation_factor.
    """
    correction_reduction: correction_reduction_cls = correction_reduction_cls
    """
    correction_reduction child of relaxation_factor.
    """
    correction_smoothing: correction_smoothing_cls = correction_smoothing_cls
    """
    correction_smoothing child of relaxation_factor.
    """
    species_correction_reduction: species_correction_reduction_cls = species_correction_reduction_cls
    """
    species_correction_reduction child of relaxation_factor.
    """
