#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class partitioning_method_for_dpm_domain(String, _HasAllowedValuesMixin):
    """
    Set the DPM domain partitioning method.
    """

    fluent_name = "partitioning-method-for-dpm-domain"

