#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class dpm_sample_contour_plots:
    fluent_name = ...
    child_names = ...
    select_sample = ...
    plotting_grid_interval_size = ...
    command_names = ...

    def prepare_expressions(self, ):
        """
        'prepare_expressions' command.
        """

