#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class direction_vector:
    fluent_name = ...
    command_names = ...

    def list_properties(self, object_at: int):
        """
        List properties of selected object.
        
        Parameters
        ----------
            object_at : int
                Select object index to delete.
        
        """

    <class 'ansys.fluent.core.solver.flobject.child_object_type'> = ...
