#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class driver_options:
    fluent_name = ...
    child_names = ...
    hardcopy_format = ...
    hardcopy_options = ...
    window_dump_cmd = ...
    post_format = ...
    command_names = ...

    def current_driver(self, ):
        """
        'current_driver' command.
        """

