#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class reorder:
    fluent_name = ...
    command_names = ...

    def band_width(self, ):
        """
        Print cell bandwidth.
        """

    def reorder_domain(self, ):
        """
        Reorder cells and faces by reverse Cuthill-McKee.
        """

    def reorder_zones(self, ):
        """
        Reorder zones by partition, type, and id.
        """

