#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class warped_face_gradient_correction:
    fluent_name = ...
    child_names = ...
    turbulence_options = ...
    command_names = ...

    def enable(self, enable: bool, gradient_correction_mode: str):
        """
        Enable Warped-Face Gradient Correction.
        
        Parameters
        ----------
            enable : bool
                'enable' child.
            gradient_correction_mode : str
                'gradient_correction_mode' child.
        
        """

