#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class specify_species_in_mole_fractions(Boolean, _HasAllowedValuesMixin):
    """
    Specify Species in Mole Fractions?.
    """

    fluent_name = "specify-species-in-mole-fractions?"

