#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class outflow:
    fluent_name = ...
    command_names = ...

    def change_type(self, zone_list: List[str], new_type: str):
        """
        'change_type' command.
        
        Parameters
        ----------
            zone_list : typing.List[str]
                'zone_list' child.
            new_type : str
                'new_type' child.
        
        """

    <class 'ansys.fluent.core.solver.flobject.child_object_type'> = ...
