#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class auto:
    fluent_name = ...
    child_names = ...
    across_zones = ...
    method = ...
    load_vector = ...
    pre_test = ...
    command_names = ...

    def use_case_file_method(self, file_partition_method: bool):
        """
        Enable the use-case-file method for auto partitioning.
        
        Parameters
        ----------
            file_partition_method : bool
                'file_partition_method' child.
        
        """

