#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class root:
    fluent_name = ...
    child_names = ...
    file = ...
    mesh = ...
    server = ...
    setup = ...
    solution = ...
    results = ...
    parametric_studies = ...
    current_parametric_study = ...
    parallel = ...
    report = ...
    command_names = ...

    def exit(self, ):
        """
        Exit program.
        """

